Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1972)

Unified Diff: content/child/blink_platform_impl_unittest.cc

Issue 2561363002: Add std::string constructors for Origin/SchemeHostPort to reduce copies (Closed)
Patch Set: fix content_unittests Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | url/origin.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/child/blink_platform_impl_unittest.cc
diff --git a/content/child/blink_platform_impl_unittest.cc b/content/child/blink_platform_impl_unittest.cc
index 28f7dfbfd27fea2d99b98b3806f1e14ff8a58c7f..97140e8eecaf0aa35f90799a6aeb7b30e91f0b5a 100644
--- a/content/child/blink_platform_impl_unittest.cc
+++ b/content/child/blink_platform_impl_unittest.cc
@@ -21,8 +21,10 @@ void CheckCastedOriginsAlreadyNormalized(
url::Origin::UnsafelyCreateOriginWithoutNormalization(
origin.protocol().utf8(), origin.host().utf8(),
origin.effectivePort());
- url::Origin non_checked_origin = url::Origin::CreateFromNormalizedTuple(
- origin.protocol().utf8(), origin.host().utf8(), origin.effectivePort());
+ url::Origin non_checked_origin =
+ url::Origin::CreateFromNormalizedTupleWithSuborigin(
+ origin.protocol().utf8(), origin.host().utf8(),
+ origin.effectivePort(), origin.suborigin().utf8());
EXPECT_EQ(checked_origin.scheme(), non_checked_origin.scheme());
EXPECT_EQ(checked_origin.host(), non_checked_origin.host());
EXPECT_EQ(checked_origin.port(), non_checked_origin.port());
@@ -144,7 +146,7 @@ TEST(BlinkPlatformTest, CastWebSecurityOrigin) {
}
// This test ensures that WebSecurityOrigins can safely use
// url::Origin::CreateFromNormalizedTuple when doing conversions.
TEST(BlinkPlatformTest, WebSecurityOriginNormalization) {
struct TestCases {
const char* url;
@@ -144,7 +146,7 @@ TEST(BlinkPlatformTest, CastWebSecurityOrigin) {
}
// This test ensures that WebSecurityOrigins can safely use
-// url::Origin::CreateFromNormalizedTuple when doing conversions.
+// url::Origin::CreateFromNormalizedTupleWithSuborigin when doing conversions.
TEST(BlinkPlatformTest, WebSecurityOriginNormalization) {
struct TestCases {
« no previous file with comments | « no previous file | url/origin.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698